package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.SysFeedback;

/**
 * feedbackService接口
 * 
 * @author ruoyi
 * @date 2023-06-11
 */
public interface ISysFeedbackService extends IService<SysFeedback>
{
    /**
     * 查询feedback
     * 
     * @param id feedback主键
     * @return feedback
     */
    public SysFeedback selectSysFeedbackById(Long id);

    /**
     * 查询feedback列表
     * 
     * @param sysFeedback feedback
     * @return feedback集合
     */
    public List<SysFeedback> selectSysFeedbackList(SysFeedback sysFeedback);

    /**
     * 新增feedback
     * 
     * @param sysFeedback feedback
     * @return 结果
     */
    public int insertSysFeedback(SysFeedback sysFeedback);

    /**
     * 修改feedback
     * 
     * @param sysFeedback feedback
     * @return 结果
     */
    public int updateSysFeedback(SysFeedback sysFeedback);

    /**
     * 批量删除feedback
     * 
     * @param ids 需要删除的feedback主键集合
     * @return 结果
     */
    public int deleteSysFeedbackByIds(Long[] ids);

    /**
     * 删除feedback信息
     * 
     * @param id feedback主键
     * @return 结果
     */
    public int deleteSysFeedbackById(Long id);
}
